gnucash maint: Multiple changes pushed

Robert Fewell bobit at code.gnucash.org
Mon Apr 22 07:16:29 EDT 2019


Updated	 via  https://github.com/Gnucash/gnucash/commit/7e9463db (commit)
	 via  https://github.com/Gnucash/gnucash/commit/3985541f (commit)
	 via  https://github.com/Gnucash/gnucash/commit/91c992d9 (commit)
	 via  https://github.com/Gnucash/gnucash/commit/d82939a9 (commit)
	from  https://github.com/Gnucash/gnucash/commit/fc0a7292 (commit)



commit 7e9463db1b46a55cd03be5ff5ab8b8508e82806e
Author: Robert Fewell <14uBobIT at gmail.com>
Date:   Mon Apr 22 12:09:55 2019 +0100

    Change a couple of accelerator keys in CSV Transaction export
    
    There are a couple of items with the same mnemonic accelerator keys so
    change them to non conflicting ones.

diff --git a/gnucash/gtkbuilder/assistant-csv-export.glade b/gnucash/gtkbuilder/assistant-csv-export.glade
index 88359e720..367e29729 100644
--- a/gnucash/gtkbuilder/assistant-csv-export.glade
+++ b/gnucash/gtkbuilder/assistant-csv-export.glade
@@ -451,7 +451,7 @@ Select the type of Export required and the separator that will be used.
                 </child>
                 <child>
                   <object class="GtkRadioButton" id="show_all">
-                    <property name="label" translatable="yes">Show _All</property>
+                    <property name="label" translatable="yes">Sho_w All</property>
                     <property name="visible">True</property>
                     <property name="can_focus">True</property>
                     <property name="receives_default">False</property>
@@ -468,7 +468,7 @@ Select the type of Export required and the separator that will be used.
                 </child>
                 <child>
                   <object class="GtkRadioButton" id="show_range">
-                    <property name="label" translatable="yes">Select Range:</property>
+                    <property name="label" translatable="yes">Select _Range:</property>
                     <property name="visible">True</property>
                     <property name="can_focus">True</property>
                     <property name="receives_default">False</property>
@@ -519,7 +519,7 @@ Select the type of Export required and the separator that will be used.
                     </child>
                     <child>
                       <object class="GtkRadioButton" id="end_date_choose">
-                        <property name="label" translatable="yes">Choo_se Date:</property>
+                        <property name="label" translatable="yes">Cho_ose Date:</property>
                         <property name="visible">True</property>
                         <property name="can_focus">True</property>
                         <property name="receives_default">False</property>

commit 3985541f48aa2e27740b449cc6e4dae86c6a6a6d
Author: Robert Fewell <14uBobIT at gmail.com>
Date:   Mon Apr 22 12:01:25 2019 +0100

    Add a select all Accounts button for CSV Transaction export.

diff --git a/gnucash/gtkbuilder/assistant-csv-export.glade b/gnucash/gtkbuilder/assistant-csv-export.glade
index 6a1da83ad..88359e720 100644
--- a/gnucash/gtkbuilder/assistant-csv-export.glade
+++ b/gnucash/gtkbuilder/assistant-csv-export.glade
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8"?>
-<!-- Generated with glade 3.20.0 -->
+<!-- Generated with glade 3.22.1 -->
 <interface>
   <requires lib="gtk+" version="3.10"/>
   <object class="GtkAssistant" id="csv_export_assistant">
@@ -12,6 +12,9 @@
     <signal name="cancel" handler="csv_export_assistant_cancel" swapped="no"/>
     <signal name="close" handler="csv_export_assistant_close" swapped="no"/>
     <signal name="prepare" handler="csv_export_assistant_prepare" swapped="no"/>
+    <child>
+      <placeholder/>
+    </child>
     <child>
       <object class="GtkBox" id="start_page">
         <property name="visible">True</property>
@@ -275,7 +278,7 @@ Select the type of Export required and the separator that will be used.
                     <property name="visible">True</property>
                     <property name="can_focus">False</property>
                     <property name="halign">start</property>
-                    <property name="label" translatable="yes"><b>_Accounts</b></property>
+                    <property name="label" translatable="yes"><b>Accounts</b></property>
                     <property name="use_markup">True</property>
                     <property name="use_underline">True</property>
                   </object>
@@ -372,6 +375,7 @@ Select the type of Export required and the separator that will be used.
                           <object class="GtkButtonBox" id="hbox99">
                             <property name="visible">True</property>
                             <property name="can_focus">False</property>
+                            <property name="orientation">vertical</property>
                             <child>
                               <object class="GtkButton" id="select_subaccounts_button">
                                 <property name="label" translatable="yes">_Select Subaccounts</property>
@@ -387,6 +391,21 @@ Select the type of Export required and the separator that will be used.
                                 <property name="position">0</property>
                               </packing>
                             </child>
+                            <child>
+                              <object class="GtkButton" id="select_all_button">
+                                <property name="label" translatable="yes">Select _All</property>
+                                <property name="visible">True</property>
+                                <property name="can_focus">True</property>
+                                <property name="receives_default">True</property>
+                                <property name="border_width">3</property>
+                                <property name="use_underline">True</property>
+                              </object>
+                              <packing>
+                                <property name="expand">False</property>
+                                <property name="fill">False</property>
+                                <property name="position">1</property>
+                              </packing>
+                            </child>
                           </object>
                           <packing>
                             <property name="expand">False</property>
@@ -420,7 +439,7 @@ Select the type of Export required and the separator that will be used.
                     <property name="visible">True</property>
                     <property name="can_focus">False</property>
                     <property name="halign">start</property>
-                    <property name="label" translatable="yes"><b>_Dates</b></property>
+                    <property name="label" translatable="yes"><b>Dates</b></property>
                     <property name="use_markup">True</property>
                     <property name="use_underline">True</property>
                   </object>
@@ -735,10 +754,5 @@ Cancel to abort.</property>
         <property name="has_padding">False</property>
       </packing>
     </child>
-    <child internal-child="action_area">
-      <object class="GtkBox" id="assistant-action_area2">
-        <property name="can_focus">False</property>
-      </object>
-    </child>
   </object>
 </interface>
diff --git a/gnucash/import-export/csv-exp/assistant-csv-export.c b/gnucash/import-export/csv-exp/assistant-csv-export.c
index 8a8d3aa4b..75ab2f479 100644
--- a/gnucash/import-export/csv-exp/assistant-csv-export.c
+++ b/gnucash/import-export/csv-exp/assistant-csv-export.c
@@ -430,6 +430,25 @@ csv_export_account_changed_cb (GtkTreeSelection *selection,
 }
 
 
+/*******************************************************
+ * csv_export_select_all_clicked_cb
+ *
+ * select all the accounts
+ *******************************************************/
+static void
+csv_export_select_all_clicked_cb (GtkWidget *widget, gpointer user_data)
+{
+    CsvExportInfo *info = user_data;
+    GtkTreeSelection *selection = gtk_tree_view_get_selection
+                                    (GTK_TREE_VIEW (info->csva.account_treeview));
+
+    gtk_tree_view_expand_all (GTK_TREE_VIEW (info->csva.account_treeview));
+    gtk_tree_selection_select_all (selection);
+
+    gtk_widget_grab_focus (info->csva.account_treeview);
+}
+
+
 /*******************************************************
  * csv_export_select_subaccounts_clicked_cb
  *
@@ -886,9 +905,14 @@ csv_export_assistant_create (CsvExportInfo *info)
         /* select subaccounts button */
         button = GTK_WIDGET(gtk_builder_get_object (builder, "select_subaccounts_button"));
         info->csva.select_button = button;
-
         g_signal_connect (G_OBJECT(button), "clicked",
                           G_CALLBACK(csv_export_select_subaccounts_clicked_cb), info);
+
+        button = GTK_WIDGET(gtk_builder_get_object (builder, "select_all_button"));
+        info->csva.select_button = button;
+        g_signal_connect (G_OBJECT(button), "clicked",
+                          G_CALLBACK(csv_export_select_all_clicked_cb), info);
+
         g_signal_connect (G_OBJECT(info->csva.account_treeview), "cursor_changed",
                           G_CALLBACK(csv_export_cursor_changed_cb), info);
 

commit 91c992d9474fafb3f4faed0e36dff60ec0964ed5
Author: Robert Fewell <14uBobIT at gmail.com>
Date:   Mon Apr 22 11:23:47 2019 +0100

    Bug 797123 - Export transactions to CSV file.
    
    When exporting transactions to CSV not all were showing up in the CSV
    file. This was due to the start and end dates not being set to the
    'start of day' and 'end of day' respectively. Also if you had specified
    a range and subsequently used the 'Show All' button the dates used
    would still be the ones used for the range.

diff --git a/gnucash/import-export/csv-exp/assistant-csv-export.h b/gnucash/import-export/csv-exp/assistant-csv-export.h
index 78ea0ff5c..b0cf99cbe 100644
--- a/gnucash/import-export/csv-exp/assistant-csv-export.h
+++ b/gnucash/import-export/csv-exp/assistant-csv-export.h
@@ -50,6 +50,8 @@ typedef struct
 
     time64     start_time;
     time64     end_time;
+    time64     earliest_time;
+    time64     latest_time;
 } CsvExportDate;
 
 typedef struct

commit d82939a9ff7253f46f6ffba987c94ab5c45b684a
Author: Robert Fewell <14uBobIT at gmail.com>
Date:   Mon Apr 22 11:14:49 2019 +0100

    Change the New Account Hierarchy glade file
    
    The 'Category Description' scroll window height was not able to be
    changed to see all the text without scrolling. Add the 'Categories' and
    the 'Category Description' scroll windows to a vertical paned widget.

diff --git a/gnucash/gtkbuilder/assistant-hierarchy.glade b/gnucash/gtkbuilder/assistant-hierarchy.glade
index 5d9770c6d..141b0e17e 100644
--- a/gnucash/gtkbuilder/assistant-hierarchy.glade
+++ b/gnucash/gtkbuilder/assistant-hierarchy.glade
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8"?>
-<!-- Generated with glade 3.20.0 -->
+<!-- Generated with glade 3.22.1 -->
 <interface>
   <requires lib="gtk+" version="3.10"/>
   <object class="GtkAssistant" id="hierarchy_assistant">
@@ -11,6 +11,9 @@
     <signal name="cancel" handler="on_cancel" swapped="no"/>
     <signal name="close" handler="on_finish" swapped="no"/>
     <signal name="prepare" handler="on_prepare" swapped="no"/>
+    <child>
+      <placeholder/>
+    </child>
     <child>
       <object class="GtkLabel" id="intro_page_label">
         <property name="visible">True</property>
@@ -96,9 +99,6 @@ Please choose the currency to use for new accounts.</property>
             <property name="position">1</property>
           </packing>
         </child>
-        <child>
-          <placeholder/>
-        </child>
       </object>
       <packing>
         <property name="title" translatable="yes">Choose Currency</property>
@@ -137,74 +137,128 @@ Select categories that correspond to the ways that you foresee you will use GnuC
             <property name="position">300</property>
             <property name="position_set">True</property>
             <child>
-              <object class="GtkPaned" id="vpaned100">
+              <object class="GtkBox" id="vbox200">
                 <property name="visible">True</property>
-                <property name="can_focus">True</property>
+                <property name="can_focus">False</property>
+                <property name="vexpand">True</property>
                 <property name="orientation">vertical</property>
-                <property name="position">200</property>
-                <property name="position_set">True</property>
+                <property name="spacing">6</property>
                 <child>
-                  <object class="GtkBox" id="vbox101">
+                  <object class="GtkPaned" id="vpaned100">
                     <property name="visible">True</property>
-                    <property name="can_focus">False</property>
-                    <property name="vexpand">True</property>
-                    <property name="border_width">6</property>
+                    <property name="can_focus">True</property>
                     <property name="orientation">vertical</property>
-                    <property name="spacing">6</property>
                     <child>
-                      <object class="GtkLabel" id="label101">
+                      <object class="GtkBox" id="vbox101">
                         <property name="visible">True</property>
                         <property name="can_focus">False</property>
-                        <property name="label" translatable="yes"><b>Categories</b></property>
-                        <property name="use_markup">True</property>
-                      </object>
-                      <packing>
-                        <property name="expand">False</property>
-                        <property name="fill">False</property>
-                        <property name="position">0</property>
-                      </packing>
-                    </child>
-                    <child>
-                      <object class="GtkScrolledWindow" id="scrolledwindow101">
-                        <property name="visible">True</property>
-                        <property name="can_focus">True</property>
                         <property name="vexpand">True</property>
-                        <property name="hscrollbar_policy">never</property>
-                        <property name="shadow_type">in</property>
+                        <property name="border_width">6</property>
+                        <property name="orientation">vertical</property>
+                        <property name="spacing">6</property>
+                        <child>
+                          <object class="GtkLabel" id="label101">
+                            <property name="visible">True</property>
+                            <property name="can_focus">False</property>
+                            <property name="label" translatable="yes"><b>Categories</b></property>
+                            <property name="use_markup">True</property>
+                          </object>
+                          <packing>
+                            <property name="expand">False</property>
+                            <property name="fill">False</property>
+                            <property name="position">0</property>
+                          </packing>
+                        </child>
                         <child>
-                          <object class="GtkTreeView" id="account_categories_tree_view">
+                          <object class="GtkScrolledWindow" id="scrolledwindow101">
                             <property name="visible">True</property>
                             <property name="can_focus">True</property>
                             <property name="vexpand">True</property>
-                            <property name="reorderable">True</property>
-                            <property name="rules_hint">True</property>
-                            <child internal-child="selection">
-                              <object class="GtkTreeSelection" id="treeview-selection100"/>
+                            <property name="hscrollbar_policy">never</property>
+                            <property name="shadow_type">in</property>
+                            <child>
+                              <object class="GtkTreeView" id="account_categories_tree_view">
+                                <property name="visible">True</property>
+                                <property name="can_focus">True</property>
+                                <property name="vexpand">True</property>
+                                <property name="reorderable">True</property>
+                                <property name="rules_hint">True</property>
+                                <child internal-child="selection">
+                                  <object class="GtkTreeSelection" id="treeview-selection100"/>
+                                </child>
+                              </object>
                             </child>
                           </object>
+                          <packing>
+                            <property name="expand">False</property>
+                            <property name="fill">True</property>
+                            <property name="position">1</property>
+                          </packing>
+                        </child>
+                        <child>
+                          <object class="GtkButtonBox" id="hbuttonbox100">
+                            <property name="visible">True</property>
+                            <property name="can_focus">False</property>
+                            <property name="border_width">6</property>
+                            <property name="layout_style">spread</property>
+                            <child>
+                              <object class="GtkButton" id="select_all_button">
+                                <property name="label" translatable="yes">_Select All</property>
+                                <property name="visible">True</property>
+                                <property name="can_focus">True</property>
+                                <property name="can_default">True</property>
+                                <property name="receives_default">True</property>
+                                <property name="use_underline">True</property>
+                                <signal name="clicked" handler="select_all_clicked" swapped="no"/>
+                              </object>
+                              <packing>
+                                <property name="expand">False</property>
+                                <property name="fill">False</property>
+                                <property name="position">0</property>
+                              </packing>
+                            </child>
+                            <child>
+                              <object class="GtkButton" id="clear_all_button">
+                                <property name="label" translatable="yes">C_lear All</property>
+                                <property name="visible">True</property>
+                                <property name="can_focus">True</property>
+                                <property name="can_default">True</property>
+                                <property name="receives_default">True</property>
+                                <property name="use_underline">True</property>
+                                <signal name="clicked" handler="clear_all_clicked" swapped="no"/>
+                              </object>
+                              <packing>
+                                <property name="expand">False</property>
+                                <property name="fill">False</property>
+                                <property name="position">1</property>
+                              </packing>
+                            </child>
+                          </object>
+                          <packing>
+                            <property name="expand">False</property>
+                            <property name="fill">True</property>
+                            <property name="position">2</property>
+                          </packing>
                         </child>
                       </object>
                       <packing>
-                        <property name="expand">False</property>
-                        <property name="fill">True</property>
-                        <property name="position">1</property>
+                        <property name="resize">True</property>
+                        <property name="shrink">False</property>
                       </packing>
                     </child>
                     <child>
-                      <object class="GtkButtonBox" id="hbuttonbox100">
+                      <object class="GtkBox" id="vbox102">
                         <property name="visible">True</property>
                         <property name="can_focus">False</property>
                         <property name="border_width">6</property>
-                        <property name="layout_style">spread</property>
+                        <property name="orientation">vertical</property>
+                        <property name="spacing">6</property>
                         <child>
-                          <object class="GtkButton" id="select_all_button">
-                            <property name="label" translatable="yes">_Select All</property>
+                          <object class="GtkLabel" id="label103">
                             <property name="visible">True</property>
-                            <property name="can_focus">True</property>
-                            <property name="can_default">True</property>
-                            <property name="receives_default">True</property>
-                            <property name="use_underline">True</property>
-                            <signal name="clicked" handler="select_all_clicked" swapped="no"/>
+                            <property name="can_focus">False</property>
+                            <property name="label" translatable="yes"><b>Category Description</b></property>
+                            <property name="use_markup">True</property>
                           </object>
                           <packing>
                             <property name="expand">False</property>
@@ -213,77 +267,48 @@ Select categories that correspond to the ways that you foresee you will use GnuC
                           </packing>
                         </child>
                         <child>
-                          <object class="GtkButton" id="clear_all_button">
-                            <property name="label" translatable="yes">C_lear All</property>
+                          <object class="GtkScrolledWindow" id="scrolledwindow100">
                             <property name="visible">True</property>
                             <property name="can_focus">True</property>
-                            <property name="can_default">True</property>
-                            <property name="receives_default">True</property>
-                            <property name="use_underline">True</property>
-                            <signal name="clicked" handler="clear_all_clicked" swapped="no"/>
+                            <property name="vexpand">True</property>
+                            <property name="shadow_type">in</property>
+                            <child>
+                              <object class="GtkTextView" id="account_types_description">
+                                <property name="visible">True</property>
+                                <property name="sensitive">False</property>
+                                <property name="can_focus">True</property>
+                                <property name="margin_left">5</property>
+                                <property name="margin_right">5</property>
+                                <property name="editable">False</property>
+                                <property name="wrap_mode">word</property>
+                                <property name="cursor_visible">False</property>
+                                <property name="accepts_tab">False</property>
+                              </object>
+                            </child>
                           </object>
                           <packing>
                             <property name="expand">False</property>
-                            <property name="fill">False</property>
+                            <property name="fill">True</property>
                             <property name="position">1</property>
                           </packing>
                         </child>
                       </object>
                       <packing>
-                        <property name="expand">False</property>
-                        <property name="fill">True</property>
-                        <property name="position">2</property>
-                      </packing>
-                    </child>
-                    <child>
-                      <object class="GtkLabel" id="label103">
-                        <property name="visible">True</property>
-                        <property name="can_focus">False</property>
-                        <property name="label" translatable="yes"><b>Category Description</b></property>
-                        <property name="use_markup">True</property>
-                      </object>
-                      <packing>
-                        <property name="expand">False</property>
-                        <property name="fill">False</property>
-                        <property name="position">3</property>
-                      </packing>
-                    </child>
-                    <child>
-                      <object class="GtkScrolledWindow" id="scrolledwindow100">
-                        <property name="visible">True</property>
-                        <property name="can_focus">True</property>
-                        <property name="shadow_type">in</property>
-                        <child>
-                          <object class="GtkTextView" id="account_types_description">
-                            <property name="visible">True</property>
-                            <property name="sensitive">False</property>
-                            <property name="can_focus">True</property>
-                            <property name="editable">False</property>
-                            <property name="wrap_mode">word</property>
-                            <property name="cursor_visible">False</property>
-                            <property name="accepts_tab">False</property>
-                          </object>
-                        </child>
-                      </object>
-                      <packing>
-                        <property name="expand">False</property>
-                        <property name="fill">True</property>
-                        <property name="position">4</property>
+                        <property name="resize">True</property>
+                        <property name="shrink">False</property>
                       </packing>
                     </child>
                   </object>
                   <packing>
-                    <property name="resize">True</property>
-                    <property name="shrink">True</property>
+                    <property name="expand">False</property>
+                    <property name="fill">True</property>
+                    <property name="position">0</property>
                   </packing>
                 </child>
-                <child>
-                  <placeholder/>
-                </child>
               </object>
               <packing>
                 <property name="resize">True</property>
-                <property name="shrink">True</property>
+                <property name="shrink">False</property>
               </packing>
             </child>
             <child>
@@ -326,7 +351,7 @@ Select categories that correspond to the ways that you foresee you will use GnuC
               </object>
               <packing>
                 <property name="resize">True</property>
-                <property name="shrink">True</property>
+                <property name="shrink">False</property>
               </packing>
             </child>
           </object>
@@ -411,13 +436,7 @@ Press `Cancel' to close this dialog without creating any new accounts.</property
       <packing>
         <property name="page_type">confirm</property>
         <property name="title" translatable="yes">Finish Account Setup</property>
-        <property name="has_padding">False</property>
       </packing>
     </child>
-    <child internal-child="action_area">
-      <object class="GtkBox" id="assistant-action_area100">
-        <property name="can_focus">False</property>
-      </object>
-    </child>
   </object>
 </interface>



Summary of changes:
 gnucash/gtkbuilder/assistant-csv-export.glade      |  36 +++-
 gnucash/gtkbuilder/assistant-hierarchy.glade       | 229 +++++++++++----------
 .../import-export/csv-exp/assistant-csv-export.c   |  80 ++++---
 .../import-export/csv-exp/assistant-csv-export.h   |   2 +
 4 files changed, 205 insertions(+), 142 deletions(-)



More information about the gnucash-changes mailing list
diff --git a/gnucash/import-export/csv-exp/assistant-csv-export.c b/gnucash/import-export/csv-exp/assistant-csv-export.c
index fdb2c8186..8a8d3aa4b 100644
--- a/gnucash/import-export/csv-exp/assistant-csv-export.c
+++ b/gnucash/import-export/csv-exp/assistant-csv-export.c
@@ -475,7 +475,7 @@ get_filter_times (CsvExportInfo *info)
         if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(info->csvd.start_date_today)))
             info->csvd.start_time = gnc_time64_get_today_start();
         else
-            info->csvd.start_time = 0;
+            info->csvd.start_time = info->csvd.earliest_time;
     }
 
     if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(info->csvd.end_date_choose)))
@@ -489,7 +489,7 @@ get_filter_times (CsvExportInfo *info)
         if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(info->csvd.end_date_today)))
             info->csvd.end_time = gnc_time64_get_today_end();
         else
-            info->csvd.end_time = gnc_time (NULL);
+            info->csvd.end_time = info->csvd.latest_time;
     }
 }
 
@@ -508,6 +508,15 @@ csv_export_show_range_cb (GtkRadioButton *button, gpointer user_data)
     g_return_if_fail (GTK_IS_RADIO_BUTTON(button));
 
     active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(button));
+
+    if (!active)
+    {
+        info->csvd.start_time = info->csvd.earliest_time;
+        info->csvd.end_time = info->csvd.latest_time;
+    }
+    else
+        get_filter_times (info);
+
     gtk_widget_set_sensitive (info->csvd.table, active);
 }
 
@@ -581,22 +590,19 @@ csv_export_end_date_cb (GtkWidget *radio, gpointer user_data)
 
 
 /*******************************************************************
- * get_earliest_in_book
+ * get_earliest_and_latest_in_book
  *
- * Find the earliest date occurring in the book.  Do this by making
- * a query and sorting by date. Since the truncated sort returns
- * only the *last* search results, sort in decreasing order.
+ * Find the earliest and latest dates occurring in the book.
  *******************************************************************/
-static time64
-get_earliest_in_book (QofBook *book)
+static void
+get_earliest_and_latest_in_book (CsvExportInfo *info, QofBook *book)
 {
     QofQuery *q;
     GSList *p1, *p2;
     GList *res;
-    time64 earliest;
+    time64 etime, ltime;
 
     q = qof_query_create_for (GNC_ID_SPLIT);
-    qof_query_set_max_results (q, 1);
     qof_query_set_book (q, book);
 
     /* Sort by transaction date */
@@ -605,24 +611,24 @@ get_earliest_in_book (QofBook *book)
     p2 = g_slist_prepend (NULL, QUERY_DEFAULT_SORT);
     qof_query_set_sort_order (q, p1, p2, NULL);
 
-    /* Reverse the sort order */
-    qof_query_set_sort_increasing (q, FALSE, FALSE, FALSE);
-
-    /* Run the query, find the earliest transaction date */
+    /* Run the query, find the earliest and latest transaction dates */
     res = qof_query_run (q);
 
     if (res)
     {
-        earliest = xaccQueryGetEarliestDateFound (q);
+        etime = xaccQueryGetEarliestDateFound (q);
+        ltime = xaccQueryGetLatestDateFound (q);
     }
     else
     {
         /* If no results, we don't want to bomb totally */
-        earliest = gnc_time (0);
+        etime = gnc_time (0);
+        ltime = gnc_time (NULL);
     }
+    info->csvd.earliest_time = gnc_time64_get_day_start (etime);
+    info->csvd.latest_time = gnc_time64_get_day_end (ltime);
 
     qof_query_destroy (q);
-    return earliest;
 }
 
 
@@ -824,7 +830,6 @@ csv_export_assistant_create (CsvExportInfo *info)
     GtkWidget *h_box;
     GtkWidget *button;
     GtkWidget *table, *hbox;
-    time64 start_time, end_time;
 
     builder = gtk_builder_new();
     gnc_builder_add_from_file  (builder , "assistant-csv-export.glade", "csv_export_assistant");
@@ -890,12 +895,11 @@ csv_export_assistant_create (CsvExportInfo *info)
         /* Set the date info */
         button = GTK_WIDGET(gtk_builder_get_object (builder, "show_range"));
 
-        /* Earliest and Latest in Book */
-        start_time = get_earliest_in_book (gnc_get_current_book());
-        end_time = gnc_time (NULL);
+        /* Get the Earliest and Latest dates in Book */
+        get_earliest_and_latest_in_book (info, gnc_get_current_book());
 
-        info->csvd.start_time = start_time;
-        info->csvd.end_time = end_time;
+        info->csvd.start_time = info->csvd.earliest_time;
+        info->csvd.end_time = info->csvd.latest_time;
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(button), FALSE);
 
         table = GTK_WIDGET(gtk_builder_get_object (builder, "select_range_table"));
@@ -912,7 +916,7 @@ csv_export_assistant_create (CsvExportInfo *info)
         hbox = GTK_WIDGET(gtk_builder_get_object (builder, "start_date_hbox"));
         gtk_box_pack_start (GTK_BOX(hbox), info->csvd.start_date, TRUE, TRUE, 0);
         gtk_widget_show (info->csvd.start_date);
-        gnc_date_edit_set_time (GNC_DATE_EDIT(info->csvd.start_date), start_time);
+        gnc_date_edit_set_time (GNC_DATE_EDIT(info->csvd.start_date), info->csvd.start_time);
         g_signal_connect (G_OBJECT(info->csvd.start_date), "date-changed",
                         G_CALLBACK(csv_export_date_changed_cb), info);
 
@@ -921,7 +925,7 @@ csv_export_assistant_create (CsvExportInfo *info)
         hbox = GTK_WIDGET(gtk_builder_get_object (builder, "end_date_hbox"));
         gtk_box_pack_start (GTK_BOX(hbox), info->csvd.end_date, TRUE, TRUE, 0);
         gtk_widget_show (info->csvd.end_date);
-        gnc_date_edit_set_time (GNC_DATE_EDIT(info->csvd.end_date), end_time);
+        gnc_date_edit_set_time (GNC_DATE_EDIT(info->csvd.end_date), info->csvd.end_time);
         g_signal_connect (G_OBJECT (info->csvd.end_date), "date-changed",
                         G_CALLBACK (csv_export_date_changed_cb), info);
 